<?php

namespace App\Http\Controllers;

// Controladores
use App\Http\Controllers\Controller;
use App\Http\Controllers\AnalitoController;
use App\Http\Controllers\MetodologiaController;
use App\Http\Controllers\ModoController;
use App\Http\Controllers\UnidadController;

// Modelos
use App\AnalitoEP15;
use Illuminate\Support\Facades\DB;

// Historicos
use App\Http\Historico\AnalitoEP15Historico;

// Requests
use Illuminate\Http\Request;
use App\Http\Requests\AnalitoEP15Request;
use App\NivelEP15;
use Exception;
use Illuminate\Support\Facades\Auth;

class AnalitoEP15Controller extends Controller
{
    protected $tableAnalitoEP15;
    protected $historico;

    public function __construct()
    {
        $this->tableAnalitoEP15 = new AnalitoEP15();
    }


    public function section(Request $req)
    {
        $modos = ModoController::list();
        $laboratorios = LaboratorioController::listAll();
        $areas = AreaController::list();
        $analitosEP15 = self::list($req->id_laboratorio, $req->id_area);
        $areasActuales = [];
        $analitosActuales = [];
        foreach ($analitosEP15 as $analitoEP15){
            if(!in_array($analitoEP15['area_id_area'], $areasActuales)){
                $areasActuales[] = $analitoEP15['area_id_area'];
            }
            if(!in_array($analitoEP15['analito_id_analito'], $analitosActuales)){
                $analitosActuales[] = $analitoEP15['analito_id_analito'];
            }
        }
        return view("analitoEP15.analitoEP15Section")
            ->with("nomSection", "SeeSectionAnalitoEP15")
            ->with("laboratorios", $laboratorios)
            ->with("areas", $areas)
            ->with("analitosEP15", $analitosEP15)
            ->with("modos", $modos)
            ->with("numeroAreasEP15", count($areasActuales))
            ->with("numeroAnalitosEP15", count($analitosActuales))
            ->with("id_reference", $req->id_reference);
    }


    public function create()
    {
        $laboratorios = LaboratorioController::listAll();
        $areas = AreaController::list();
        $analitos = AnalitoController::list();
        $analizadores = AnalizadorController::list();
        $unidades = UnidadController::list();
        return view("analitoEP15.analitoEP15Create")
            ->with("laboratorios", $laboratorios)
            ->with("areas", $areas)
            ->with("analitos", $analitos)
            ->with("analizadores", $analizadores)
            ->with("unidades", $unidades);
    }


    public function index(Request $req)
    {
        $analitosEP15 = self::list($req->id_laboratorio, $req->id_area);
        return view("analitoEP15.analitoEP15Index")
            ->with("analitosEP15", $analitosEP15);
    }


    public function store(AnalitoEP15Request $req)
    {   
        $user = Auth::user();
        $client = DB::table("super_admin")
        ->where("id", $user->super_admin_id)
        ->first();
        $users = DB::table("analito_ep15")
        ->where("client", $user->super_admin_id)
        ->count();
        if ($users < $client->num_project) {
            $this->historico = new AnalitoEP15Historico();
                $this->tableAnalitoEP15->analito_id_analito = $req->id_analito;
                $this->tableAnalitoEP15->analizador_id_analizador = $req->id_analizador;
                $this->tableAnalitoEP15->unidad_id_unidad = $req->id_unidad;
                $this->tableAnalitoEP15->lote_reactivo = $req->lote_reactivo;
                $this->tableAnalitoEP15->lote_calibrador = $req->lote_calibrador;
                $this->tableAnalitoEP15->etmp = $req->etmp;
                $this->tableAnalitoEP15->estado = 1;
                $this->tableAnalitoEP15->laboratorio_id_laboratorio = $req->id_laboratorio;
                $this->tableAnalitoEP15->area_id_area = $req->id_area;
                $this->tableAnalitoEP15->material_utilizado = $req->material_utilizado;
                $this->tableAnalitoEP15->num_niveles = $req->num_niveles;
                $this->tableAnalitoEP15->fecha_inicio = $req->fecha_inicio;
                $this->tableAnalitoEP15->client = $user->super_admin_id;
                $this->tableAnalitoEP15->usuario_id_usuario = $user->id_usuario;
                $this->historico->store("store", $req);
                $this->tableAnalitoEP15->save();
        }
        else{
            throw new Exception('División por cero.');
        }
    }


    public static function list($laboratorio = "", $area = "")
    {

        if (Auth::user()->rol_id_rol == 5) {
            $tableAnalitoEP15 = new AnalitoEP15();
            $obj_bd = $tableAnalitoEP15
                ->select(
                    "area.*",
                    "laboratorio.*",
                    "usuario.nombres",
                    "analizador.*",
                    "analito.*",
                    "unidad.*",
                    "analito_ep15.*",
                    "super_admin.name as client_name"
                )
                ->join("area", "area.id_area", "=", "analito_ep15.area_id_area")
                ->join("laboratorio", "laboratorio.id_laboratorio", "=", "analito_ep15.laboratorio_id_laboratorio")
                ->join("usuario", "usuario.id_usuario", "=", "analito_ep15.usuario_id_usuario")
                ->join("analizador", "analizador.id_analizador", "=", "analito_ep15.analizador_id_analizador")
                ->join("analito", "analito.id_analito", "=", "analito_ep15.analito_id_analito")
                ->join("unidad", "unidad.id_unidad", "=", "analito_ep15.unidad_id_unidad")
                ->join("super_admin", "super_admin.id", "=", "analito_ep15.client")
                ->orderBy("analito_ep15.estado", "desc")
                ->orderBy("laboratorio.no_laboratorio", "asc")
                ->orderBy("area.nom_area", "asc");

            if ($laboratorio != "" && $area != "") { // Si tanto el area como el laboratorio estan definidos
                $obj_bd->where([
                    ["laboratorio.id_laboratorio", "=", $laboratorio],
                    ["area.id_area", "=", $area]
                ]);
            } else if ($laboratorio != "") { // Si solo el laboratorio esta definido
                $obj_bd->where("laboratorio.id_laboratorio", $laboratorio);
            } else if ($area != "") { // Si solo el area esta definida
                $obj_bd->where("area.id_area", $area);
            }
            return $obj_bd->get();
        } else {
            if (Auth::user()->rol_id_rol == 1) { // Administrador total
                $tableAnalitoEP15 = new AnalitoEP15();
                $obj_bd = $tableAnalitoEP15
                    ->select(
                        "area.*",
                        "laboratorio.*",
                        "usuario.*",
                        "analizador.*",
                        "analito.*",
                        "unidad.*",
                        "analito_ep15.*"
                    )
                    ->join("area", "area.id_area", "=", "analito_ep15.area_id_area")
                    ->join("laboratorio", "laboratorio.id_laboratorio", "=", "analito_ep15.laboratorio_id_laboratorio")
                    ->join("analizador", "analizador.id_analizador", "=", "analito_ep15.analizador_id_analizador")
                    ->join("analito", "analito.id_analito", "=", "analito_ep15.analito_id_analito")
                    ->join("unidad", "unidad.id_unidad", "=", "analito_ep15.unidad_id_unidad")
                    ->join("usuario", "usuario.id_usuario", "=", "analito_ep15.usuario_id_usuario")
                    ->where("analito_ep15.client", Auth::user()->super_admin_id)
                    ->orderBy("analito_ep15.estado", "desc")
                    ->orderBy("laboratorio.no_laboratorio", "asc")
                    ->orderBy("area.nom_area", "asc");

                if ($laboratorio != "" && $area != "") { // Si tanto el area como el laboratorio estan definidos
                    $obj_bd->where([
                        ["laboratorio.id_laboratorio", "=", $laboratorio],
                        ["area.id_area", "=", $area]
                    ]);
                } else if ($laboratorio != "") { // Si solo el laboratorio esta definido
                    $obj_bd->where("laboratorio.id_laboratorio", $laboratorio);
                } else if ($area != "") { // Si solo el area esta definida
                    $obj_bd->where("area.id_area", $area);
                }
                return $obj_bd->get();
            } else { // Cualquier otro tipo de usuario
                $tableAnalitoEP15 = new AnalitoEP15();
                $obj_bd = $tableAnalitoEP15
                    ->select(
                        "area.*",
                        "laboratorio.*",
                        "usuario.*",
                        "analizador.*",
                        "analito.*",
                        "unidad.*",
                        "analito_ep15.*"
                    )
                    ->join("area", "area.id_area", "=", "analito_ep15.area_id_area")
                    ->join("laboratorio", "laboratorio.id_laboratorio", "=", "analito_ep15.laboratorio_id_laboratorio")
                    ->join("analizador", "analizador.id_analizador", "=", "analito_ep15.analizador_id_analizador")
                    ->join("analito", "analito.id_analito", "=", "analito_ep15.analito_id_analito")
                    ->join("unidad", "unidad.id_unidad", "=", "analito_ep15.unidad_id_unidad")
                    ->join("usuario_laboratorio", "laboratorio.id_laboratorio", "=", "usuario_laboratorio.laboratorio_id_laboratorio")
                    ->join("usuario", "usuario.id_usuario", "=", "analito_ep15.usuario_id_usuario")
                    ->where("analito_ep15.client", Auth::user()->super_admin_id)
                    ->orderBy("analito_ep15.estado", "desc")
                    ->orderBy("laboratorio.no_laboratorio", "asc")
                    ->orderBy("area.nom_area", "asc");

                if ($laboratorio != "" && $area != "") { // Si tanto el area como el laboratorio estan definidos
                    $obj_bd->where([
                        ["laboratorio.id_laboratorio", "=", $laboratorio],
                        ["area.id_area", "=", $area],
                        ["usuario_laboratorio.usuario_id_usuario", "=", Auth::user()->id_usuario]
                    ]);
                } else if ($laboratorio != "") { // Si solo el laboratorio esta definido
                    $obj_bd->where([
                        ["laboratorio.id_laboratorio", $laboratorio],
                        ["usuario_laboratorio.usuario_id_usuario", "=", Auth::user()->id_usuario]
                    ]);
                } else if ($area != "") { // Si solo el area esta definida
                    $obj_bd->where([
                        ["area.id_area", $area],
                        ["usuario_laboratorio.usuario_id_usuario", "=", Auth::user()->id_usuario]
                    ]);
                } else {
                    $obj_bd->where([
                        ["usuario_laboratorio.usuario_id_usuario", "=", Auth::user()->id_usuario]
                    ]);
                }

                return $obj_bd->get();
            }
        }
    }

    public static function listByCorrida()
    {
        $tableAnalitoEP15 = new AnalitoEP15();
        return $tableAnalitoEP15
            ->select(
                "analizador.*",
                "analito.*",
                "unidad.*",
                "analito_ep15.*",
                "analito_ep15.estado as estado_analito_ep15"
            )
            ->join("analizador", "analizador.id_analizador", "=", "analito_ep15.analizador_id_analizador")
            ->join("analito", "analito.id_analito", "=", "analito_ep15.analito_id_analito")
            ->join("unidad", "unidad.id_unidad", "=", "analito_ep15.unidad_id_unidad")
            ->get();
    }


    public static function listItem($id_referencia)
    {
        $tableAnalitoEP15 = new AnalitoEP15();
        return $tableAnalitoEP15
            ->select(
                "analizador.*",
                "analito.*",
                "unidad.*",
                "analito_ep15.*",
                "analito_ep15.estado as estado_analito_ep15"
            )
            ->join("analizador", "analizador.id_analizador", "=", "analito_ep15.analizador_id_analizador")
            ->join("analito", "analito.id_analito", "=", "analito_ep15.analito_id_analito")
            ->join("unidad", "unidad.id_unidad", "=", "analito_ep15.unidad_id_unidad")
            ->where("analito_ep15.id_analito_ep15", $id_referencia)
            ->first();
    }

    public static function analitoLevel($id_referencia, $nivel)
    {
        $tableNivel = new NivelEP15();
        return $tableNivel
            ->select(
                "nivel.*"
            )
            ->where([["nivel.analito_ep15_id_analito_ep15", $id_referencia], ["nivel.nivel", $nivel]])
            ->first();
    }


    public function edit(Request $req)
    {
        $analitoEP15 = self::listItem($req->id_reference);
        $laboratorios = LaboratorioController::listAll();
        $areas = AreaController::list();
        $analitos = AnalitoController::list();
        $analizadores = AnalizadorController::list();
        $unidades = UnidadController::list();
        return view("analitoEP15.analitoEP15Edit")
            ->with("analitoEP15", $analitoEP15)
            ->with("laboratorios", $laboratorios)
            ->with("areas", $areas)
            ->with("analitos", $analitos)
            ->with("analizadores", $analizadores)
            ->with("unidades", $unidades);
    }



    public function destroy(Request $req)
    {

        $this->historico = new AnalitoEP15Historico();
        $this->historico->store("destroy", $req);

        $this->tableAnalitoEP15
            ->where("id_analito_ep15", $req->id)
            ->delete();
    }


    public function status(Request $req)
    {

        $this->historico = new AnalitoEP15Historico();
        $this->historico->store("status", $req);

        $statusNow = $this->tableAnalitoEP15
            ->where("id_analito_ep15", $req->id)
            ->first()
            ->estado;

        $registroUpdate = $this->tableAnalitoEP15
            ->where("id_analito_ep15", $req->id);

        if ($statusNow == 1) {
            $registroUpdate->update(["estado" => 0]);
        } else {
            $registroUpdate->update(["estado" => 1]);
        }
    }

    public function show(Request $req)
    {
        $analitoEP15 = self::listItem($req->id);

        return view("analitoEP15.analitoEP15Show")
            ->with("analitoEP15", $analitoEP15)
            ->with("campo", $req->campo);
    }

    public function verUsuarios(Request $req){
        $analito_EP15 = self::ListItem($req->id_reference);
        $users = UsuarioController::listUsersByLabForProject("analito_ep15","id_analito_ep15",$analito_EP15->id_analito_ep15);
        return view("analitoEP15.analitoEP15Access")
            ->with("analito_EP15", $analito_EP15)
            ->with("users",$users);
    }


    public function update(AnalitoEP15Request $req)
    {
        $this->historico = new AnalitoEP15Historico();
        $this->historico->store("update", $req);

        $analitoEP15 = $this->tableAnalitoEP15
            ->where("id_analito_ep15", $req->id)
            ->first();

        $analitoEP15->update([
            "laboratorio_id_laboratorio" => $req->id_laboratorio,
            "area_id_area" => $req->id_area,
            "fecha_inicio" => $req->fecha_inicio,
            "material_utilizado" => $req->material_utilizado,
            "num_niveles" => $req->num_niveles,
            "analito_id_analito" => $req->id_analito,
            "analizador_id_analizador" => $req->id_analizador,
            "unidad_id_unidad" => $req->id_unidad,
            "etmp" => $req->etmp,
            "lote_reactivo" => $req->lote_reactivo,
            "lote_calibrador" => $req->lote_calibrador
        ]);
    }
}
