<?php

namespace App\Http\Controllers;

// Controladores
use App\Http\Controllers\Controller;
use App\Http\Controllers\AreaController;
use App\Http\Controllers\CorridaAreaController;
use App\Http\Controllers\ProyectoEP15Controller;

// Modelos
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use App\Analizador;

// Request
use Illuminate\Http\Request;
use App\Http\Requests\AnalizadorRequest;

// Historicos
use App\Http\Historico\AnalizadorHistorico;

class AnalizadorController extends Controller{

    protected $tableAnalizador;
    protected $historico;

    public function __construct(){
        $this->tableAnalizador = new Analizador();
    }


    public function section(){
        $analizadores = $this->tableAnalizador
            ->select(
                "analizador.id_analizador as id_analizador",
                "analizador.super_admin_id",
                "area.nom_area as nom_area",
                "analizador.nom_analizador as nom_analizador",
                "analizador.estado as estado"
            )
            ->join("area", "area.id_area", "=", "analizador.area_id_area")
            // ->whereIn("analizador.super_admin_id", [0, Auth::user()->super_admin_id])
            ->orderBy("analizador.estado","desc")
            ->orderBy("area.nom_area","asc")
            ->orderBy("analizador.nom_analizador","asc")
            ->get();

        $areas = AreaController::list();

        return view("analizador.analizadorSection")
            ->with("analizadores",$analizadores)
            ->with("areas",$areas)
            ->with("nomSection","SeeSectionAnalizador");
    }


    public function index(){
        $analizadores = $this->tableAnalizador
            ->select(
                "analizador.id_analizador as id_analizador",
                "analizador.super_admin_id",
                "area.nom_area as nom_area",
                "analizador.nom_analizador as nom_analizador",
                "analizador.estado as estado"
            )
            ->join("area", "area.id_area", "=", "analizador.area_id_area")
            // ->whereIn("analizador.super_admin_id", [0, Auth::user()->super_admin_id])
            ->orderBy("analizador.estado","desc")
            ->orderBy("area.nom_area","asc")
            ->orderBy("analizador.nom_analizador","asc")
            ->get();

        return view("analizador.analizadorIndex")
            ->with("analizadores",$analizadores);
    }


    public function store(AnalizadorRequest $req){

        $this->historico = new AnalizadorHistorico();
        $this->historico->store("store", $req);

        $this->tableAnalizador->area_id_area = $req->id_area;
        $this->tableAnalizador->nom_analizador = $req->nombre;
        $this->tableAnalizador->super_admin_id = Auth::user()->super_admin_id;
        $this->tableAnalizador->save();
    }


    public static function list(){
        $tableAnalizador = new Analizador();
        return $tableAnalizador
            ->select(
                "analizador.id_analizador as id_analizador",
                "analizador.super_admin_id",
                "area.nom_area as nom_area",
                "analizador.nom_analizador as nom_analizador"
            )
            ->join("area","area.id_area","=","analizador.area_id_area")
            // ->whereIn("analizador.super_admin_id", [0, Auth::user()->super_admin_id])
            ->where("analizador.estado",1)
            ->orderBy("area.nom_area")
            ->orderBy("analizador.nom_analizador")
            ->get();
    }

    public static function listByAreaCorrida($id_corrida_area){
        $id_area = CorridaAreaController::getAreaById($id_corrida_area);
        $tableAnalizador = new Analizador();
        return $tableAnalizador
            ->select(
                "analizador.id_analizador as id_analizador",
                "analizador.super_admin_id",
                "area.nom_area as nom_area",
                "analizador.nom_analizador as nom_analizador"
            )
            ->join("area","area.id_area","=","analizador.area_id_area")
            // ->whereIn("analizador.super_admin_id", [0, Auth::user()->super_admin_id])
            ->where([
                ["analizador.estado",1],
                ["area.id_area","=", $id_area]
            ])
            ->orderBy("area.nom_area")
            ->orderBy("analizador.nom_analizador")
            ->get();
    }

    public static function listByProyectoEP15($id_proyecto_ep15){
        $id_area = ProyectoEP15Controller::getAreaById($id_proyecto_ep15);
        $tableAnalizador = new Analizador();
        return $tableAnalizador
            ->select(
                "analizador.id_analizador as id_analizador",
                "analizador.super_admin_id",
                "area.nom_area as nom_area",
                "analizador.nom_analizador as nom_analizador"
            )
            ->join("area","area.id_area","=","analizador.area_id_area")
            // ->whereIn("analizador.super_admin_id", [0, Auth::user()->super_admin_id])
            ->where([
                ["analizador.estado",1],
                ["area.id_area","=", $id_area]
            ])
            ->orderBy("area.nom_area")
            ->orderBy("analizador.nom_analizador")
            ->get();
    }

    public static function listItem($id){
        $tableAnalizador = new Analizador();
        $analizador = $tableAnalizador
            ->select(
                "analizador.id_analizador as id_analizador",
                "analizador.super_admin_id",
                "area.id_area as id_area",
                "area.nom_area as nom_area",
                "analizador.nom_analizador as nom_analizador",
                "analizador.estado as estado"
                )
            ->join("area","area.id_area","=","analizador.area_id_area")
            // ->whereIn("analizador.super_admin_id", [0, Auth::user()->super_admin_id])
            ->where("analizador.id_analizador",$id)
            ->first();
        return $analizador;
    }


    public function listHTML(Request $req){ // Lista con base a las corridas de área
        $id_area = CorridaAreaController::getAreaById($req->id);

        $analizadores = $this->tableAnalizador
            ->select(
                "analizador.id_analizador as id_analizador",
                "analizador.super_admin_id",
                "area.nom_area as nom_area",
                "analizador.nom_analizador as nom_analizador"
            )
            ->join("area","area.id_area","=","analizador.area_id_area")
            // ->whereIn("analizador.super_admin_id", [0, Auth::user()->super_admin_id])
            ->where([
                ["area.id_area",$id_area],
                ["analizador.estado",1]
            ])
            ->orderBy("area.nom_area")
            ->orderBy("analizador.nom_analizador")
            ->get();

        return view("analizador.analizadorList")
            ->with("analizadores",$analizadores);
    }

    public function listHTMLEP15(Request $req){
        $id_area = ProyectoEP15Controller::getAreaById($req->id);

        $analizadores = $this->tableAnalizador
            ->select(
                "analizador.id_analizador as id_analizador",
                "analizador.super_admin_id",
                "area.nom_area as nom_area",
                "analizador.nom_analizador as nom_analizador"
            )
            ->join("area","area.id_area","=","analizador.area_id_area")
            // ->whereIn("analizador.super_admin_id", [0, Auth::user()->super_admin_id])
            ->where([
                ["area.id_area",$id_area],
                ["analizador.estado",1]
            ])
            ->orderBy("area.nom_area")
            ->orderBy("analizador.nom_analizador")
            ->get();

        return view("analizador.analizadorList")
            ->with("analizadores",$analizadores);
    }

    public function destroy(Request $req){

        $this->historico = new AnalizadorHistorico();
        $this->historico->store("destroy", $req);

        $this->tableAnalizador
            ->where("id_analizador",$req->id)
            ->delete();
    }


    public function status(Request $req){

        $this->historico = new AnalizadorHistorico();
        $this->historico->store("status", $req);

        $statusNow = $this->tableAnalizador
            ->where("id_analizador",$req->id)
            ->first()
            ->estado;

        $registroUpdate = $this->tableAnalizador
            ->where("id_analizador",$req->id);

        if($statusNow == 1){
            $registroUpdate->update(["estado" => 0]);
        } else {
            $registroUpdate->update(["estado" => 1]);
        }
    }


    public function edit(Request $req){
        $analizador = $this->tableAnalizador
            ->select(
                "id_analizador",
                "area_id_area",
                "nom_analizador",
                "estado"
            )
            ->where("id_analizador",$req->id)
            // ->whereIn("analizador.super_admin_id", [0, Auth::user()->super_admin_id])
            ->first();

        $areas = AreaController::list();

        return view("analizador.analizadorEdit")
            ->with("analizador",$analizador)
            ->with("areas",$areas)
            ->with("campo",$req->campo);
    }


    public function show(Request $req){
        $analizador = $this->tableAnalizador
            ->select(
                "analizador.id_analizador as id_analizador",
                "analizador.super_admin_id",
                "area.nom_area as nom_area",
                "analizador.nom_analizador as nom_analizador"
            )
            ->join("area","area.id_area","=","analizador.area_id_area")
            // ->whereIn("analizador.super_admin_id", [0, Auth::user()->super_admin_id])
            ->where("analizador.id_analizador",$req->id)
            ->first();

        return view("analizador.analizadorShow")
            ->with("analizador",$analizador)
            ->with("campo",$req->campo);
    }


    public function update(AnalizadorRequest $req){

        $this->historico = new AnalizadorHistorico();
        $this->historico->store("update", $req);

        $analizador = $this->tableAnalizador
            ->where("id_analizador",$req->id)
            ->first();

        switch($req->campo){
            case "area":
                $analizador->update(["area_id_area" => $req->id_area]);
                break;
            case "nombre":
                $analizador->update(["nom_analizador" => $req->nombre]);
                break;
        }
    }
}
