<?php

namespace App\Http\Controllers;

// Controladores
use App\Http\Controllers\Controller;
use App\Http\Controllers\AnalitoController;
use App\Http\Controllers\MetodologiaController;
use App\Http\Controllers\ModoController;
use App\Http\Controllers\UnidadController;

// Modelos
use App\CorridaAnalito;
use Illuminate\Support\Facades\DB;

// Historicos
use App\Http\Historico\CorridaAnalitoHistorico;

// Requests
use Illuminate\Http\Request;
use App\Http\Requests\CorridaAnalitoRequest;
use Illuminate\Support\Facades\Auth;

class CorridaAnalitoController extends Controller{
    protected $tableCorridaAnalito;
    protected $historico;
    
    public function __construct(){
        $this->tableCorridaAnalito = new CorridaAnalito();
    }
    

    public function section(Request $req){
    
        $modos = ModoController::list();
        $laboratorios = LaboratorioController::listAll();
        $areas = AreaController::list();
        $analitosCorrida = self::list($req->id_laboratorio, $req->id_area);
        $areasActuales = [];
        $analitosActuales = [];
        foreach ($analitosCorrida as $analitoCorrida){
            if(!in_array($analitoCorrida['area_id_area'], $areasActuales)){
                $areasActuales[] = $analitoCorrida['area_id_area'];
            }
            if(!in_array($analitoCorrida['analito_id_analito'], $analitosActuales)){
                $analitosActuales[] = $analitoCorrida['analito_id_analito'];
            }
        }
        return view("corridaAnalito.corridaAnalitoSection")
            ->with("nomSection", "SeeSectionCorridaAnalito")
            ->with("laboratorios", $laboratorios)
            ->with("areas", $areas)
            ->with("analitosCorrida", $analitosCorrida)
            ->with("modos", $modos)
            ->with("numeroAreasEP09", count($areasActuales))
            ->with("numeroAnalitosEP09", count($analitosActuales))
            ->with("id_reference", $req->id_reference);
    }


    public function create(){
        $laboratorios = LaboratorioController::listAll();
        $areas = AreaController::list();
        $modos = ModoController::list();
        $unidades = UnidadController::list();
        $analizadores = AnalizadorController::list();
        $metodologias = MetodologiaController::list();
        $analitos = AnalitoController::list();
        return view("corridaAnalito.corridaAnalitoCreate")
            ->with("laboratorios",$laboratorios)
            ->with("areas",$areas)
            ->with("modos",$modos)
            ->with("unidades",$unidades)
            ->with("analizadores",$analizadores)
            ->with("metodologias",$metodologias)
            ->with("analitos",$analitos);
    }
    
    
    public function index(Request $req){
        
        $analitosCorrida = self::list($req->id_laboratorio, $req->id_area);

        return view("corridaAnalito.corridaAnalitoIndex")
            ->with("analitosCorrida",$analitosCorrida);
    }
    
    
    public function store(CorridaAnalitoRequest $req){
        $user = Auth::user();
        $client = DB::table("super_admin")
        ->where("id", $user->super_admin_id)
        ->first();
        $users = DB::table("corrida_analito")
        ->where("client", $user->super_admin_id)
        ->count();
        if ($users < $client->num_project) {
            $this->historico = new CorridaAnalitoHistorico();
            $this->historico->store("store", $req);
            $this->tableCorridaAnalito->laboratorio_id_laboratorio = $req->id_laboratorio;
            $this->tableCorridaAnalito->area_id_area = $req->id_area;
            $this->tableCorridaAnalito->fecha_inicio = $req->fecha_inicio;
            $this->tableCorridaAnalito->client = $user->super_admin_id;
            $this->tableCorridaAnalito->usuario_id_usuario = $user->id_usuario;
            $this->tableCorridaAnalito->analito_id_analito = $req->id_analito;
            $this->tableCorridaAnalito->metodologia_prueba = $req->id_metodologia_prueba;
            $this->tableCorridaAnalito->metodologia_comparacion = $req->id_metodologia_comparacion;
            $this->tableCorridaAnalito->analizador_prueba = $req->id_analizador_prueba;
            $this->tableCorridaAnalito->analizador_comparacion = $req->id_analizador_comparacion;
            $this->tableCorridaAnalito->modo_metodologia_prueba = $req->id_modo_metodologia_prueba;
            $this->tableCorridaAnalito->modo_metodologia_comparacion = $req->id_modo_metodologia_comparacion;
            $this->tableCorridaAnalito->unidad_metodologia_prueba = $req->id_unidad_prueba;
            $this->tableCorridaAnalito->unidad_metodologia_comparacion = $req->id_unidad_comparacion;
            $this->tableCorridaAnalito->diferencia_maxima_permisible = $req->diferencia_maxima_permisible;
            $this->tableCorridaAnalito->limite_aps = $req->limite_aps;
            $this->tableCorridaAnalito->save();
        } else {
            throw new Exception('División por cero.');
        }
    }

    public static function listItem($id_referencia){
        $tableCorridaAnalito = new CorridaAnalito();
        return $tableCorridaAnalito
            ->select(
                "analito.*",
                "area.*",
                "metodologia_prueba.nom_metodologia as nom_metodologia_prueba",
                "metodologia_comparacion.nom_metodologia as nom_metodologia_comparacion",
                "modo_metodologia_prueba.nom_modo as nom_modo_metodologia_prueba",
                "modo_metodologia_comparacion.nom_modo as nom_modo_metodologia_comparacion",
                "unidad_metodologia_prueba.nom_unidad as nom_unidad_metodologia_prueba",
                "unidad_metodologia_comparacion.nom_unidad as nom_unidad_metodologia_comparacion",
                "laboratorio.*",
                "analizador_prueba.nom_analizador as nom_analizador_prueba",
                "analizador_comparacion.nom_analizador as nom_analizador_comparacion",
                "corrida_analito.*"
            )
            ->join("area", "area.id_area", "=", "corrida_analito.area_id_area")
            ->join("analito", "analito.id_analito", "=", "corrida_analito.analito_id_analito")
            ->join("metodologia as metodologia_prueba", "metodologia_prueba.id_metodologia", "=", "corrida_analito.metodologia_prueba")
            ->join("metodologia as metodologia_comparacion", "metodologia_comparacion.id_metodologia", "=", "corrida_analito.metodologia_comparacion")
            ->join("modo as modo_metodologia_prueba", "modo_metodologia_prueba.id_modo", "=", "corrida_analito.modo_metodologia_prueba")
            ->join("modo as modo_metodologia_comparacion", "modo_metodologia_comparacion.id_modo", "=", "corrida_analito.modo_metodologia_comparacion")
            ->join("unidad as unidad_metodologia_prueba", "unidad_metodologia_prueba.id_unidad", "=", "corrida_analito.unidad_metodologia_prueba")
            ->join("unidad as unidad_metodologia_comparacion", "unidad_metodologia_comparacion.id_unidad", "=", "corrida_analito.unidad_metodologia_comparacion")
            ->join("laboratorio", "laboratorio.id_laboratorio", "=", "corrida_analito.laboratorio_id_laboratorio")
            ->join("analizador as analizador_prueba", "analizador_prueba.id_analizador", "=", "corrida_analito.analizador_prueba")
            ->join("analizador as analizador_comparacion", "analizador_comparacion.id_analizador", "=", "corrida_analito.analizador_comparacion")
            ->where("corrida_analito.id_corrida_analito", $id_referencia)
            ->first();
    }

    public static function list($laboratorio = "",$area = ""){

        if(Auth::user()->rol_id_rol == 5) {
            $tableCorridaAnalito= new CorridaAnalito();
            $obj_bd = $tableCorridaAnalito
                ->select(
                    "area.*",
                    "laboratorio.*",
                    "usuario.*",
                    "super_admin.name as client_name",
                    "analito.*",
                    "area.*",
                    "metodologia_prueba.nom_metodologia as nom_metodologia_prueba",
                    "metodologia_comparacion.nom_metodologia as nom_metodologia_comparacion",
                    "modo_metodologia_prueba.nom_modo as nom_modo_metodologia_prueba",
                    "modo_metodologia_comparacion.nom_modo as nom_modo_metodologia_comparacion",
                    "unidad_metodologia_prueba.nom_unidad as nom_unidad_metodologia_prueba",
                    "unidad_metodologia_comparacion.nom_unidad as nom_unidad_metodologia_comparacion",
                    "laboratorio.*",
                    "analizador_prueba.nom_analizador as nom_analizador_prueba",
                    "analizador_comparacion.nom_analizador as nom_analizador_comparacion",
                    "corrida_analito.*"
                )
                ->join("area", "area.id_area", "=", "corrida_analito.area_id_area")
                ->join("laboratorio", "laboratorio.id_laboratorio", "=", "corrida_analito.laboratorio_id_laboratorio")
                ->join("usuario", "usuario.id_usuario", "=", "corrida_analito.usuario_id_usuario")
                ->join("super_admin", "super_admin.id", "=", "corrida_analito.client")
                ->join("analito", "analito.id_analito", "=", "corrida_analito.analito_id_analito")
                ->join("metodologia as metodologia_prueba", "metodologia_prueba.id_metodologia", "=", "corrida_analito.metodologia_prueba")
                ->join("metodologia as metodologia_comparacion", "metodologia_comparacion.id_metodologia", "=", "corrida_analito.metodologia_comparacion")
                ->join("modo as modo_metodologia_prueba", "modo_metodologia_prueba.id_modo", "=", "corrida_analito.modo_metodologia_prueba")
                ->join("modo as modo_metodologia_comparacion", "modo_metodologia_comparacion.id_modo", "=", "corrida_analito.modo_metodologia_comparacion")
                ->join("unidad as unidad_metodologia_prueba", "unidad_metodologia_prueba.id_unidad", "=", "corrida_analito.unidad_metodologia_prueba")
                ->join("unidad as unidad_metodologia_comparacion", "unidad_metodologia_comparacion.id_unidad", "=", "corrida_analito.unidad_metodologia_comparacion")
                ->join("analizador as analizador_prueba", "analizador_prueba.id_analizador", "=", "corrida_analito.analizador_prueba")
                ->join("analizador as analizador_comparacion", "analizador_comparacion.id_analizador", "=", "corrida_analito.analizador_comparacion")
                ->orderBy("corrida_analito.estado","desc")
                ->orderBy("laboratorio.no_laboratorio","asc")
                ->orderBy("area.nom_area","asc");

            if($laboratorio != "" && $area != ""){ // Si tanto el area como el laboratorio estan definidos
                $obj_bd->where([
                    ["laboratorio.id_laboratorio","=",$laboratorio],
                    ["area.id_area","=",$area]
                ]);
            } else if($laboratorio != "") { // Si solo el laboratorio esta definido
                $obj_bd->where("laboratorio.id_laboratorio", $laboratorio);
            } else if($area != ""){ // Si solo el area esta definida
                $obj_bd->where("area.id_area", $area);
            }
            return $obj_bd->get();
        } else {
            if(Auth::user()->rol_id_rol == 1){ // Administrador total
                $tableCorridaAnalito= new CorridaAnalito();
                $obj_bd = $tableCorridaAnalito
                    ->select(
                        "area.*",
                        "laboratorio.*",
                        "usuario.*",
                        "corrida_analito.*",
                        "corrida_analito.estado as estado_corrida_analito",
                        "corrida_analito.id_corrida_analito as id_corrida_analito",
                        "analito.*",
                        "area.*",
                        "metodologia_prueba.nom_metodologia as nom_metodologia_prueba",
                        "metodologia_comparacion.nom_metodologia as nom_metodologia_comparacion",
                        "modo_metodologia_prueba.nom_modo as nom_modo_metodologia_prueba",
                        "modo_metodologia_comparacion.nom_modo as nom_modo_metodologia_comparacion",
                        "unidad_metodologia_prueba.nom_unidad as nom_unidad_metodologia_prueba",
                        "unidad_metodologia_comparacion.nom_unidad as nom_unidad_metodologia_comparacion",
                        "laboratorio.*",
                        "analizador_prueba.nom_analizador as nom_analizador_prueba",
                        "analizador_comparacion.nom_analizador as nom_analizador_comparacion"
                    )
                    ->join("area", "area.id_area", "=", "corrida_analito.area_id_area")
                    ->join("laboratorio", "laboratorio.id_laboratorio", "=", "corrida_analito.laboratorio_id_laboratorio")
                    ->join("usuario", "usuario.id_usuario", "=", "corrida_analito.usuario_id_usuario")
                    ->join("analito", "analito.id_analito", "=", "corrida_analito.analito_id_analito")
                    ->join("metodologia as metodologia_prueba", "metodologia_prueba.id_metodologia", "=", "corrida_analito.metodologia_prueba")
                    ->join("metodologia as metodologia_comparacion", "metodologia_comparacion.id_metodologia", "=", "corrida_analito.metodologia_comparacion")
                    ->join("modo as modo_metodologia_prueba", "modo_metodologia_prueba.id_modo", "=", "corrida_analito.modo_metodologia_prueba")
                    ->join("modo as modo_metodologia_comparacion", "modo_metodologia_comparacion.id_modo", "=", "corrida_analito.modo_metodologia_comparacion")
                    ->join("unidad as unidad_metodologia_prueba", "unidad_metodologia_prueba.id_unidad", "=", "corrida_analito.unidad_metodologia_prueba")
                    ->join("unidad as unidad_metodologia_comparacion", "unidad_metodologia_comparacion.id_unidad", "=", "corrida_analito.unidad_metodologia_comparacion")
                    ->join("analizador as analizador_prueba", "analizador_prueba.id_analizador", "=", "corrida_analito.analizador_prueba")
                    ->join("analizador as analizador_comparacion", "analizador_comparacion.id_analizador", "=", "corrida_analito.analizador_comparacion")
                    ->where("corrida_analito.client",Auth::user()->super_admin_id)
                    ->orderBy("corrida_analito.estado","desc")
                    ->orderBy("laboratorio.no_laboratorio","asc")
                    ->orderBy("area.nom_area","asc");

                if($laboratorio != "" && $area != ""){ // Si tanto el area como el laboratorio estan definidos
                    $obj_bd->where([
                        ["laboratorio.id_laboratorio","=",$laboratorio],
                        ["area.id_area","=",$area]
                    ]);
                } else if($laboratorio != "") { // Si solo el laboratorio esta definido
                    $obj_bd->where("laboratorio.id_laboratorio", $laboratorio);
                } else if($area != ""){ // Si solo el area esta definida
                    $obj_bd->where("area.id_area", $area);
                }
                return $obj_bd->get();
            } else { // Cualquier otro tipo de usuario
                $tableCorridaAnalito= new CorridaAnalito();
                $obj_bd = $tableCorridaAnalito
                    ->select(
                        "area.*",
                        "laboratorio.*",
                        "usuario.*",
                        "corrida_analito.*",
                        "corrida_analito.estado as estado_corrida_analito",
                        "corrida_analito.id_corrida_analito as id_corrida_analito",
                        "analito.*",
                        "area.*",
                        "metodologia_prueba.nom_metodologia as nom_metodologia_prueba",
                        "metodologia_comparacion.nom_metodologia as nom_metodologia_comparacion",
                        "modo_metodologia_prueba.nom_modo as nom_modo_metodologia_prueba",
                        "modo_metodologia_comparacion.nom_modo as nom_modo_metodologia_comparacion",
                        "unidad_metodologia_prueba.nom_unidad as nom_unidad_metodologia_prueba",
                        "unidad_metodologia_comparacion.nom_unidad as nom_unidad_metodologia_comparacion",
                        "laboratorio.*",
                        "analizador_prueba.nom_analizador as nom_analizador_prueba",
                        "analizador_comparacion.nom_analizador as nom_analizador_comparacion"
                    )
                    ->join("area", "area.id_area", "=", "corrida_analito.area_id_area")
                    ->join("laboratorio", "laboratorio.id_laboratorio", "=", "corrida_analito.laboratorio_id_laboratorio")
                    ->join("usuario_laboratorio", "laboratorio.id_laboratorio", "=", "usuario_laboratorio.laboratorio_id_laboratorio")
                    ->join("usuario", "usuario.id_usuario", "=", "corrida_analito.usuario_id_usuario")
                    ->join("analito", "analito.id_analito", "=", "corrida_analito.analito_id_analito")
                    ->join("metodologia as metodologia_prueba", "metodologia_prueba.id_metodologia", "=", "corrida_analito.metodologia_prueba")
                    ->join("metodologia as metodologia_comparacion", "metodologia_comparacion.id_metodologia", "=", "corrida_analito.metodologia_comparacion")
                    ->join("modo as modo_metodologia_prueba", "modo_metodologia_prueba.id_modo", "=", "corrida_analito.modo_metodologia_prueba")
                    ->join("modo as modo_metodologia_comparacion", "modo_metodologia_comparacion.id_modo", "=", "corrida_analito.modo_metodologia_comparacion")
                    ->join("unidad as unidad_metodologia_prueba", "unidad_metodologia_prueba.id_unidad", "=", "corrida_analito.unidad_metodologia_prueba")
                    ->join("unidad as unidad_metodologia_comparacion", "unidad_metodologia_comparacion.id_unidad", "=", "corrida_analito.unidad_metodologia_comparacion")
                    ->join("analizador as analizador_prueba", "analizador_prueba.id_analizador", "=", "corrida_analito.analizador_prueba")
                    ->join("analizador as analizador_comparacion", "analizador_comparacion.id_analizador", "=", "corrida_analito.analizador_comparacion")
                    ->where("corrida_analito.client",Auth::user()->super_admin_id)
                    ->orderBy("corrida_analito.estado","desc")
                    ->orderBy("laboratorio.no_laboratorio","asc")
                    ->orderBy("area.nom_area","asc");

                if($laboratorio != "" && $area != ""){ // Si tanto el area como el laboratorio estan definidos
                    $obj_bd->where([
                        ["laboratorio.id_laboratorio","=",$laboratorio],
                        ["area.id_area","=",$area],
                        ["usuario_laboratorio.usuario_id_usuario", "=", Auth::user()->id_usuario]
                    ]);
                } else if($laboratorio != "") { // Si solo el laboratorio esta definido
                    $obj_bd->where([
                        ["laboratorio.id_laboratorio", $laboratorio],
                        ["usuario_laboratorio.usuario_id_usuario", "=", Auth::user()->id_usuario]
                    ]);
                } else if($area != ""){ // Si solo el area esta definida
                    $obj_bd->where([
                        ["area.id_area", $area],
                        ["usuario_laboratorio.usuario_id_usuario", "=", Auth::user()->id_usuario]
                    ]);
                } else {
                    $obj_bd->where([
                        ["usuario_laboratorio.usuario_id_usuario", "=", Auth::user()->id_usuario]
                    ]);
                }

                return $obj_bd->get();
            }
        }
    }

    

    public function edit(Request $req){
        $corridaAnalito = self::listItem($req->id_reference);
        $laboratorios = LaboratorioController::listAll();
        $areas = AreaController::list();
        $modos = ModoController::list();
        $unidades = UnidadController::list();
        $analizadores = AnalizadorController::list();
        $metodologias = MetodologiaController::list();
        $analitos = AnalitoController::list();
        return view("corridaAnalito.corridaAnalitoEdit",
        compact("corridaAnalito","laboratorios","areas","modos","unidades","analizadores","metodologias","analitos"));
    }
    
    
    public function destroy(Request $req){

        $this->historico = new CorridaAnalitoHistorico();
        $this->historico->store("destroy", $req);

        $this->tableCorridaAnalito
            ->where("id_corrida_analito",$req->id)
            ->delete();
    }
    
    
    public function status(Request $req){

        $this->historico = new CorridaAnalitoHistorico();
        $this->historico->store("status", $req);

        $statusNow = $this->tableCorridaAnalito
            ->where("id_corrida_analito",$req->id)
            ->first()
            ->estado; 

        $registroUpdate = $this->tableCorridaAnalito
            ->where("id_corrida_analito",$req->id);
        
        if($statusNow == 1){
            $registroUpdate->update(["estado" => 0]);
        } else {
            $registroUpdate->update(["estado" => 1]);
        }
    }
    
    public function show(Request $req){


        $corridaAnalito = self::listItem($req->id);
        
        return view("corridaAnalito.corridaAnalitoShow")
            ->with("corridaAnalito",$corridaAnalito)
            ->with("campo",$req->campo);
    }
    
    
    public function update(CorridaAnalitoRequest $req){
        $this->historico = new CorridaAnalitoHistorico();
        $this->historico->store("update", $req);

        $corridaAnalito = $this->tableCorridaAnalito
            ->where("id_corrida_analito",$req->id)
            ->first();

        $corridaAnalito->update([
            "laboratorio_id_laboratorio" => $req->id_laboratorio,
            "area_id_area" => $req->id_area,
            "fecha_inicio" => $req->fecha_inicio,
            "id_analito" => $req->id_analito,
            "id_metodologia_prueba" => $req->id_metodologia_prueba,
            "id_analizador_prueba" => $req->id_analizador_prueba,
            "id_modo_metodologia_prueba" => $req->id_modo_metodologia_prueba,
            "id_unidad_prueba" => $req->id_unidad_prueba,
            "id_metodologia_comparacion" => $req->id_metodologia_comparacion,
            "id_analizador_comparacion" => $req->id_analizador_comparacion,
            "id_modo_metodologia_comparacion" => $req->id_modo_metodologia_comparacion,
            "id_unidad_comparacion" => $req->id_unidad_comparacion,
            "diferencia_maxima_permisible" => $req->diferencia_maxima_permisible,
            "limite_aps" => $req->limite_aps,
        ]);
    }

    
    public function verUsuarios(Request $req){
        $corridaAnalito = self::listItem($req->id_reference);
        $users = UsuarioController::listUsersByLabForProject("corrida_analito","id_corrida_analito",$corridaAnalito->id_corrida_analito);
        return view("corridaAnalito.corridaAnalitoAccess")
            ->with("corridaAnalito",$corridaAnalito)
            ->with("users",$users);
    }

}
