<?php

namespace App\Http\Controllers;

// Controladores
use App\Http\Controllers\Controller;
use App\Http\Controllers\AreaController;
// Modelos
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use App\Metodologia;

// Request
use Illuminate\Http\Request;
use App\Http\Requests\MetodologiaRequest;

// Historicos
use App\Http\Historico\MetodologiaHistorico;

class MetodologiaController extends Controller{
    protected $tableMetodologia;
    protected $historico;

    public function __construct(){
        $this->tableMetodologia = new Metodologia();
    }


    public function section(){
        $metodologias = $this->tableMetodologia
            ->select(
                "metodologia.id_metodologia as id_metodologia",
                "metodologia.super_admin_id",
                "area.nom_area as nom_area",
                "metodologia.nom_metodologia as nom_metodologia",
                "metodologia.estado as estado"
            )
            ->join("area", "area.id_area", "=", "metodologia.area_id_area")
            // ->whereIn("metodologia.super_admin_id", [0, Auth::user()->super_admin_id])
            ->orderBy("metodologia.estado","desc")
            ->orderBy("area.nom_area","asc")
            ->orderBy("metodologia.nom_metodologia","asc")
            ->get();

        $areas = AreaController::list();

        return view("metodologia.metodologiaSection")
            ->with("metodologias",$metodologias)
            ->with("areas",$areas)
            ->with("nomSection","SeeSectionMetodologia");
    }


    public function index(){
        $metodologias = $this->tableMetodologia
            ->select(
                "metodologia.id_metodologia as id_metodologia",
                "metodologia.super_admin_id",
                "area.nom_area as nom_area",
                "metodologia.nom_metodologia as nom_metodologia",
                "metodologia.estado as estado"
            )
            ->join("area", "area.id_area", "=", "metodologia.area_id_area")
            // ->whereIn("metodologia.super_admin_id", [0, Auth::user()->super_admin_id])
            ->orderBy("metodologia.estado","desc")
            ->orderBy("area.nom_area","asc")
            ->orderBy("metodologia.nom_metodologia","asc")
            ->get();

        return view("metodologia.metodologiaIndex")
            ->with("metodologias",$metodologias);
    }


    public function store(MetodologiaRequest $req){

        $this->historico = new MetodologiaHistorico();
        $this->historico->store("store", $req);

        $this->tableMetodologia->area_id_area = $req->id_area;
        $this->tableMetodologia->nom_metodologia = $req->nombre;
        $this->tableMetodologia->super_admin_id = Auth::user()->super_admin_id;
        $this->tableMetodologia->save();
    }


    public static function list(){
        $tableMetodologia = new Metodologia();
        return $tableMetodologia
            ->select(
                "metodologia.id_metodologia as id_metodologia",
                "metodologia.super_admin_id",
                "area.nom_area as nom_area",
                "metodologia.nom_metodologia as nom_metodologia"
            )
            ->join("area","area.id_area","=","metodologia.area_id_area")
            // ->whereIn("metodologia.super_admin_id", [0, Auth::user()->super_admin_id])
            ->where("metodologia.estado",1)
            ->orderBy("area.nom_area")
            ->orderBy("metodologia.nom_metodologia")
            ->get();
    }

    public static function listItem($id){
        $tableMetodologia = new Metodologia();
        $metodologia = $tableMetodologia
            ->select(
                "metodologia.id_metodologia as id_metodologia",
                "metodologia.super_admin_id",
                "area.id_area as id_area",
                "area.nom_area as nom_area",
                "metodologia.nom_metodologia as nom_metodologia",
                "metodologia.estado as estado"
                )
            ->join("area","area.id_area","=","metodologia.area_id_area")
            // ->whereIn("metodologia.super_admin_id", [0, Auth::user()->super_admin_id])
            ->where("metodologia.id_metodologia",$id)
            ->first();
        return $metodologia;
    }

    public function destroy(Request $req){

        $this->historico = new MetodologiaHistorico();
        $this->historico->store("destroy", $req);

        $this->tableMetodologia
            ->where("id_metodologia",$req->id)
            ->delete();
    }


    public function status(Request $req){

        $this->historico = new MetodologiaHistorico();
        $this->historico->store("status", $req);

        $statusNow = $this->tableMetodologia
            ->where("id_metodologia",$req->id)
            ->first()
            ->estado;

        $registroUpdate = $this->tableMetodologia
            ->where("id_metodologia",$req->id);

        if($statusNow == 1){
            $registroUpdate->update(["estado" => 0]);
        } else {
            $registroUpdate->update(["estado" => 1]);
        }
    }


    public function edit(Request $req){
        $metodologia = $this->tableMetodologia
            ->select(
                "id_metodologia",
                "area_id_area",
                "nom_metodologia",
                "estado"
            )
            ->where("id_metodologia",$req->id)
            ->first();

        $areas = AreaController::list();

        return view("metodologia.metodologiaEdit")
            ->with("metodologia",$metodologia)
            ->with("areas",$areas)
            ->with("campo",$req->campo);
    }


    public function show(Request $req){
        $metodologia = $this->tableMetodologia
            ->select(
                "metodologia.id_metodologia as id_metodologia",
                "metodologia.super_admin_id",
                "area.nom_area as nom_area",
                "metodologia.nom_metodologia as nom_metodologia"
            )
            ->join("area","area.id_area","=","metodologia.area_id_area")
            // ->whereIn("metodologia.super_admin_id", [0, Auth::user()->super_admin_id])
            ->where("metodologia.id_metodologia",$req->id)
            ->first();

        return view("metodologia.metodologiaShow")
            ->with("metodologia",$metodologia)
            ->with("campo",$req->campo);
    }


    public function update(MetodologiaRequest $req){

        $this->historico = new MetodologiaHistorico();
        $this->historico->store("update", $req);

        $metodologia = $this->tableMetodologia
            ->where("id_metodologia",$req->id)
            ->first();

        switch($req->campo){
            case "area":
                $metodologia->update(["area_id_area" => $req->id_area]);
                break;
            case "nombre":
                $metodologia->update(["nom_metodologia" => $req->nombre]);
                break;
        }
    }
}
