<?php

namespace App\Http\Controllers;

// Controladores
use App\Http\Controllers\Controller;
use App\Http\Controllers\AreaController;
// Modelos
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use App\Unidad;

// Request
use Illuminate\Http\Request;
use App\Http\Requests\UnidadRequest;

// Historicos
use App\Http\Historico\UnidadHistorico;

class UnidadController extends Controller{

    protected $tableUnidad;
    protected $historico;

    public function __construct(){
        $this->tableUnidad = new Unidad();
    }


    public function section(){
        $unidades = $this->tableUnidad
            ->select(
                "unidad.id_unidad as id_unidad",
                "unidad.super_admin_id",
                "area.nom_area as nom_area",
                "unidad.nom_unidad as nom_unidad",
                "unidad.estado as estado"
            )
            ->join("area", "area.id_area", "=", "unidad.area_id_area")
            // ->whereIn("unidad.super_admin_id", [0, Auth::user()->super_admin_id])
            ->orderBy("unidad.estado","desc")
            ->orderBy("area.nom_area","asc")
            ->orderBy("unidad.nom_unidad","asc")
            ->get();

        $areas = AreaController::list();

        return view("unidad.unidadSection")
            ->with("unidades",$unidades)
            ->with("areas",$areas)
            ->with("nomSection","SeeSectionUnidad");
    }


    public function index(){
        $unidades = $this->tableUnidad
            ->select(
                "unidad.id_unidad as id_unidad",
                "unidad.super_admin_id",
                "area.nom_area as nom_area",
                "unidad.nom_unidad as nom_unidad",
                "unidad.estado as estado"
            )
            ->join("area", "area.id_area", "=", "unidad.area_id_area")
            // ->whereIn("unidad.super_admin_id", [0, Auth::user()->super_admin_id])
            ->orderBy("unidad.estado","desc")
            ->orderBy("area.nom_area","asc")
            ->orderBy("unidad.nom_unidad","asc")
            ->get();

        return view("unidad.unidadIndex")
            ->with("unidades",$unidades);
    }


    public function store(UnidadRequest $req){

        $this->historico = new UnidadHistorico();
        $this->historico->store("store", $req);

        $this->tableUnidad->area_id_area = $req->id_area;
        $this->tableUnidad->nom_unidad = $req->nombre;
        $this->tableUnidad->super_admin_id = Auth::user()->super_admin_id;
        $this->tableUnidad->save();
    }


    public static function list(){
        $tableUnidad = new Unidad();
        return $tableUnidad
            ->select(
                "unidad.id_unidad as id_unidad",
                "unidad.super_admin_id",
                "area.nom_area as nom_area",
                "unidad.nom_unidad as nom_unidad"
            )
            ->join("area","area.id_area","=","unidad.area_id_area")
            // ->whereIn("unidad.super_admin_id", [0, Auth::user()->super_admin_id])
            ->where("unidad.estado",1)
            ->orderBy("area.nom_area")
            ->orderBy("unidad.nom_unidad")
            ->get();
    }

    public static function listItem($id){
        $tableUnidad = new Unidad();
        $unidad = $tableUnidad
            ->select(
                "unidad.id_unidad as id_unidad",
                "unidad.super_admin_id",
                "area.id_area as id_area",
                "area.nom_area as nom_area",
                "unidad.nom_unidad as nom_unidad",
                "unidad.estado as estado"
                )
            ->join("area","area.id_area","=","unidad.area_id_area")
            // ->whereIn("unidad.super_admin_id", [0, Auth::user()->super_admin_id])
            ->where("unidad.id_unidad",$id)
            ->first();
        return $unidad;
    }

    public function destroy(Request $req){

        $this->historico = new UnidadHistorico();
        $this->historico->store("destroy", $req);

        $this->tableUnidad
            ->where("id_unidad",$req->id)
            ->delete();
    }


    public function status(Request $req){

        $this->historico = new UnidadHistorico();
        $this->historico->store("status", $req);

        $statusNow = $this->tableUnidad
            ->where("id_unidad",$req->id)
            ->first()
            ->estado;

        $registroUpdate = $this->tableUnidad
            ->where("id_unidad",$req->id);

        if($statusNow == 1){
            $registroUpdate->update(["estado" => 0]);
        } else {
            $registroUpdate->update(["estado" => 1]);
        }
    }


    public function edit(Request $req){
        $unidad = $this->tableUnidad
            ->select(
                "id_unidad",
                "area_id_area",
                "nom_unidad",
                "estado"
            )
            ->where("id_unidad",$req->id)
            ->first();

        $areas = AreaController::list();

        return view("unidad.unidadEdit")
            ->with("unidad",$unidad)
            ->with("areas",$areas)
            ->with("campo",$req->campo);
    }


    public function show(Request $req){
        $unidad = $this->tableUnidad
            ->select(
                "unidad.id_unidad as id_unidad",
                "unidad.super_admin_id",
                "area.nom_area as nom_area",
                "unidad.nom_unidad as nom_unidad"
            )
            ->join("area","area.id_area","=","unidad.area_id_area")
            // ->whereIn("unidad.super_admin_id", [0, Auth::user()->super_admin_id])
            ->where("unidad.id_unidad",$req->id)
            ->first();

        return view("unidad.unidadShow")
            ->with("unidad",$unidad)
            ->with("campo",$req->campo);
    }


    public function update(UnidadRequest $req){

        $this->historico = new UnidadHistorico();
        $this->historico->store("update", $req);

        $unidad = $this->tableUnidad
            ->where("id_unidad",$req->id)
            ->first();

        switch($req->campo){
            case "area":
                $unidad->update(["area_id_area" => $req->id_area]);
                break;
            case "nombre":
                $unidad->update(["nom_unidad" => $req->nombre]);
                break;
        }
    }
}
