<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

class ProyectoEP17Request extends FormRequest {
    public function authorize(){
        return true;
    }
    
    public function rules(){
        if(isset($this->id)){ // Actualizacion
            return [
                "id_laboratorio" => [
                    "required",
                    "min:1",
                    "max:40"
                ],
                "id_area" => [
                    "required",
                    "min:1",
                    "max:40"
                ],
                "id_analito" => [
                    "required",
                    "min:1",
                    "max:40",
                ],
                "id_analizador" => [
                    "required",
                    "min:1",
                    "max:40"
                ],
                "id_unidad" => [
                    "required",
                    "min:1",
                    "max:40"
                ],
                'n_lote_reactivo_1' => [
                    "required",
                    "min:2",
                    "max:100",
                ],
                'n_lote_reactivo_2' => [
                    "required",
                    "min:2",
                    "max:100",
                ],
                'fecha' => [
                    "required",
                    "min:2",
                    "max:100",
                ],
                'decision_femenina' => [
                    "required",
                    "min:2",
                    "max:100",
                ],
                'decision_masculina' => [
                    "required",
                    "min:2",
                    "max:100",
                ],
                'pctb' => [
                    "required",
                    "min:0",
                    "max:100",
                    "numeric"
                ],
                "aps" => [
                    "required",
                    "min:0",
                    "max:100",
                    "numeric"
                ]
            ];
        } else { // Cuando es un registro
            return [
                "id_laboratorio" => [
                    "required",
                    "min:1",
                    "max:40"
                ],
                "id_area" => [
                    "required",
                    "min:1",
                    "max:40"
                ],
                "id_analito" => [
                    "required",
                    "min:1",
                    "max:40",
                ],
                "id_analizador" => [
                    "required",
                    "min:1",
                    "max:40"
                ],
                "id_unidad" => [
                    "required",
                    "min:1",
                    "max:40"
                ],
                'n_lote_reactivo_1' => [
                    "required",
                    "min:2",
                    "max:100",
                ],
                'n_lote_reactivo_2' => [
                    "required",
                    "min:2",
                    "max:100",
                ],
                'fecha' => [
                    "required",
                    "min:2",
                    "max:100",
                ],
                'decision_femenina' => [
                    "required",
                    "min:2",
                    "max:100",
                ],
                'decision_masculina' => [
                    "required",
                    "min:2",
                    "max:100",
                ],
                'pctb' => [
                    "required",
                    "min:0",
                    "max:100",
                    "numeric"
                ],
                "aps" => [
                    "required",
                    "min:0",
                    "max:100",
                    "numeric"
                ]
            ];
        }   
    }
    
    
    public function attributes(){
        return [
            'id_laboratorio' => 'laboratorio',
            'id_area' => 'área',
            'id_analito' => 'analito',
            'id_analizador' => 'analizador',
            'id_unidad' => 'unidad',
            'n_lote_reactivo_1' => 'número de lote de reactivo 1',
            'n_lote_reactivo_2' => 'número de lote de reactivo 2',
            'fecha' => 'fecha',
            'decision_femenina' => 'decisión femenina',
            'decision_masculina' => 'decisión masculina',
            'lote_reactivos_1' => 'lote de reactivos 1',
            'lote_reactivos_2' => 'lote de reactivos 2',
            'pctb' => 'PctB',
            'aps' => 'APS'
        ];
    }
    

    public function messages(){
        return [
            'id_laboratorio.required' => 'El campo es obligatorio',
            'id_area.required' => 'El campo es obligatorio',
            'id_analito.required' => 'El campo es obligatorio',
            'id_analizador.required' => 'El campo es obligatorio',
            'id_unidad.required' => 'El campo es obligatorio',
            'n_lote_reactivo_1.required' => 'El campo es obligatorio',
            'n_lote_reactivo_2.required' => 'El campo es obligatorio',
            'fecha.required' => 'El campo es obligatorio',
            'decision_femenina.required' => 'El campo es obligatorio',
            'decision_masculina.required' => 'El campo es obligatorio',
            'pctb.required' => 'El campo es obligatorio',
            'aps.required' => 'El campo es obligatorio',
        ];
    }
}