<?php

namespace App\Http\Controllers;

// Controladores
// use App\AnalitoEP17;
use App\Http\Controllers\Controller;
use App\Http\Controllers\LaboratorioController;
use App\Http\Controllers\AnalitoController;
use App\Http\Controllers\UnidadController;
use App\Http\Controllers\AnalizadorController;
use App\Http\Controllers\UsuarioController;
use Illuminate\Support\Facades\DB;

// Modelos
use App\ProyectoEP17;

// Historicos
use App\Http\Historico\ProyectoEP17Historico;

// Requests
use Illuminate\Http\Request;
use App\Http\Requests\ProyectoEP17Request;

// Sesion
use Auth;
use Exception;

class ProyectoEP17Controller extends Controller
{

    protected $tableProyectoEP17;
    protected $historico;

    public function __construct()
    {
        $this->tableProyectoEP17 = new ProyectoEP17();
    }


    public function section(Request $req)
    {
        $proyectosEP17 = self::list($req->id_laboratorio, $req->id_analito);
        $laboratorios = LaboratorioController::listAll();
        $areas = AreaController::list();
        $areasActuales = [];
        $analitosActuales = [];
        foreach ($proyectosEP17 as $proyectoEP17) {
           if(!in_array($proyectoEP17['area_id_area'], $areasActuales)){
                $areasActuales[] = $proyectoEP17['area_id_area'];
            }
            if(!in_array($proyectoEP17['analito_id_analito'], $analitosActuales)){
                $analitosActuales[] = $proyectoEP17['analito_id_analito'];
            }
        }
        return view("proyectoEP17.proyectoEP17Section")
            ->with("nomSection", "SeeSectionProyectoEP17")
            ->with("laboratorios", $laboratorios)
            ->with("areas", $areas)
            ->with("proyectosEP17", $proyectosEP17)
            ->with("numeroAreasEP17", count($areasActuales))
            ->with("numeroAnalitosEP17", count($analitosActuales));
    }

    public function create()
    {
        $laboratorios = LaboratorioController::listAll();
        $areas = AreaController::list();
        $analitos = AnalitoController::list();
        $unidades = UnidadController::list();
        $analizadores = AnalizadorController::list();
        return view("proyectoEP17.proyectoEP17Create")
            ->with("laboratorios", $laboratorios)
            ->with("areas", $areas)
            ->with("analitos", $analitos)
            ->with("unidades", $unidades)
            ->with("analizadores", $analizadores);
    }

    public function index(Request $req)
    {

        $proyectosEP17 = self::list($req->id_laboratorio, $req->id_analito);
        $areasActuales = [];
        $analitosActuales = [];
        foreach ($proyectosEP17 as $proyectoEP17) {
           if(!in_array($proyectoEP17['area_id_area'], $areasActuales)){
                $areasActuales[] = $proyectoEP17['area_id_area'];
            }
            if(!in_array($proyectoEP17['analito_id_analito'], $analitosActuales)){
                $analitosActuales[] = $proyectoEP17['analito_id_analito'];
            }
        }
        return view("proyectoEP17.proyectoEP17Index")
            ->with("proyectosEP17", $proyectosEP17)
            ->with("numeroAreasEP17", count($areasActuales))
            ->with("numeroAnalitosEP17", count($analitosActuales));
    }

    public function store(ProyectoEP17Request $req)
    {
        $user = Auth::user();
        $client = DB::table("super_admin")
            ->where("id", $user->super_admin_id)
            ->first();
        $users = DB::table("proyecto_ep17")
            ->where("client", $user->super_admin_id)
            ->count();

        if ($users < $client->num_project) {
            $this->historico = new ProyectoEP17Historico();
            $this->historico->store("store", $req);
            $this->tableProyectoEP17->laboratorio_id_laboratorio = $req->id_laboratorio;
            $this->tableProyectoEP17->area_id_area = $req->id_area;
            $this->tableProyectoEP17->analito_id_analito = $req->id_analito;
            $this->tableProyectoEP17->analizador_id_analizador = $req->id_analizador;
            $this->tableProyectoEP17->unidad_id_unidad = $req->id_unidad;
            $this->tableProyectoEP17->fecha = $req->fecha;
            $this->tableProyectoEP17->n_lote_reactivo_2 = $req->n_lote_reactivo_2;
            $this->tableProyectoEP17->n_lote_reactivo_1 = $req->n_lote_reactivo_1;
            $this->tableProyectoEP17->decision_femenina = $req->decision_femenina;
            $this->tableProyectoEP17->decision_masculina = $req->decision_masculina;
            $this->tableProyectoEP17->pctb = $req->pctb;
            $this->tableProyectoEP17->aps = $req->aps;
            $this->tableProyectoEP17->client = $user->super_admin_id;
            $this->tableProyectoEP17->usuario_id_usuario = $user->id_usuario;
            $this->tableProyectoEP17->save();
        } else {
            throw new Exception('División por cero.');
        }
    }

    public static function getAnalitosEp17($idProyectoEP17)
    {
        $analitos = DB::table("analito_ep17")
            ->select("analito.nom_analito")
            ->join("analito", "analito_ep17.analito_id_analito", "=", "analito.id_analito")
            ->where("proyecto_ep17_id_proyecto_ep17", $idProyectoEP17)
            ->get();
        $listaAnalitos = [];
        foreach ($analitos as $analito) {
            $listaAnalitos[] = $analito->nom_analito;
        }
        if (count($listaAnalitos) > 0) {
            return implode(", ", $listaAnalitos);
        } else {
            return "No hay analitos";
        }
    }

    public static function list($laboratorio = "", $area = "")
    {
        if (Auth::user()->rol_id_rol == 5) {
            $tableProyectoEP17 = new ProyectoEP17();
            $obj_bd = $tableProyectoEP17
                ->select(
                    "laboratorio.*",
                    "area.*",
                    "usuario.*",
                    "analizador.*",
                    "analito.*",
                    "unidad.*",
                    "proyecto_ep17.*",
                    "proyecto_ep17.estado as estado_proyecto_ep17",
                    "super_admin.name as client_name"
                )
                ->join("laboratorio", "laboratorio.id_laboratorio", "=", "proyecto_ep17.laboratorio_id_laboratorio")
                ->join("area", "area.id_area", "=", "proyecto_ep17.area_id_area")
                ->join("usuario", "usuario.id_usuario", "=", "proyecto_ep17.usuario_id_usuario")
                ->join("analizador", "analizador.id_analizador", "=", "proyecto_ep17.analizador_id_analizador")
                ->join("analito", "analito.id_analito", "=", "proyecto_ep17.analito_id_analito")
                ->join("unidad", "unidad.id_unidad", "=", "proyecto_ep17.unidad_id_unidad")
                ->join("super_admin", "super_admin.id", "=", "proyecto_ep17.client")
                ->orderBy("proyecto_ep17.estado", "desc")
                ->orderBy("laboratorio.no_laboratorio", "asc")
                ->orderBy("area.nom_area", "asc");

            if ($laboratorio != "") { // Si el laboratorio estan definidos
                $obj_bd->where([
                    ["laboratorio.id_laboratorio", "=", $laboratorio],
                    ["area.id_area", "=", $area]
                ]);
            } else if ($laboratorio != "") { // Si solo el laboratorio esta definido
                $obj_bd->where("laboratorio.id_laboratorio", $laboratorio);
            } else if ($area != "") { // Si solo el area esta definida
                $obj_bd->where("area.id_area", $area);
            }
            return $obj_bd->get();
        } else {
            if (Auth::user()->rol_id_rol == 1) { // Administrador total
                $tableProyectoEP17 = new ProyectoEP17();
                $obj_bd = $tableProyectoEP17
                    ->select(
                        "laboratorio.*",
                        "area.*",
                        "usuario.*",
                        "analizador.*",
                        "analito.*",
                        "unidad.*",
                        "proyecto_ep17.*",
                        "proyecto_ep17.estado as estado_proyecto_ep17"
                    )
                    ->join("laboratorio", "laboratorio.id_laboratorio", "=", "proyecto_ep17.laboratorio_id_laboratorio")
                    ->join("area", "area.id_area", "=", "proyecto_ep17.area_id_area")
                    ->join("usuario", "usuario.id_usuario", "=", "proyecto_ep17.usuario_id_usuario")
                    ->join("analizador", "analizador.id_analizador", "=", "proyecto_ep17.analizador_id_analizador")
                    ->join("analito", "analito.id_analito", "=", "proyecto_ep17.analito_id_analito")
                    ->join("unidad", "unidad.id_unidad", "=", "proyecto_ep17.unidad_id_unidad")
                    ->orderBy("proyecto_ep17.estado", "desc")
                    ->orderBy("laboratorio.no_laboratorio", "asc")
                    ->orderBy("area.nom_area", "asc");

                if ($laboratorio != "") { // Si el laboratorio estan definidos
                    $obj_bd->where([
                        ["laboratorio.id_laboratorio", "=", $laboratorio],
                        ["area.id_area", "=", $area]
                    ]);
                } else if ($laboratorio != "") { // Si solo el laboratorio esta definido
                    $obj_bd->where("laboratorio.id_laboratorio", $laboratorio);
                } else if ($area != "") { // Si solo el area esta definida
                    $obj_bd->where("area.id_area", $area);
                }
                return $obj_bd->get();
            } else { // Cualquier otro tipo de usuario
                $tableProyectoEP17 = new ProyectoEP17();
                $obj_bd = $tableProyectoEP17
                    ->select(
                        "laboratorio.*",
                        "area.*",
                        "usuario.*",
                        "analizador.*",
                        "analito.*",
                        "unidad.*",
                        "proyecto_ep17.*",
                        "proyecto_ep17.estado as estado_proyecto_ep17"
                    )
                    ->join("laboratorio", "laboratorio.id_laboratorio", "=", "proyecto_ep17.laboratorio_id_laboratorio")
                    ->join("area", "area.id_area", "=", "proyecto_ep17.area_id_area")
                    ->join("usuario", "usuario.id_usuario", "=", "proyecto_ep17.usuario_id_usuario")
                    ->join("analizador", "analizador.id_analizador", "=", "proyecto_ep17.analizador_id_analizador")
                    ->join("analito", "analito.id_analito", "=", "proyecto_ep17.analito_id_analito")
                    ->join("unidad", "unidad.id_unidad", "=", "proyecto_ep17.unidad_id_unidad")
                    ->join("usuario_laboratorio", "laboratorio.id_laboratorio", "=", "usuario_laboratorio.laboratorio_id_laboratorio")
                    ->orderBy("proyecto_ep17.estado", "desc")
                    ->orderBy("laboratorio.no_laboratorio", "asc")
                    ->orderBy("area.nom_area", "asc");
    
                    if ($laboratorio != "" && $area != "") { // Si tanto el area como el laboratorio estan definidos
                        $obj_bd->where([
                            ["laboratorio.id_laboratorio", "=", $laboratorio],
                            ["area.id_area", "=", $area],
                            ["usuario_laboratorio.usuario_id_usuario", "=", Auth::user()->id_usuario]
                        ]);
                    } else if ($laboratorio != "") { // Si solo el laboratorio esta definido
                        $obj_bd->where([
                            ["laboratorio.id_laboratorio", $laboratorio],
                            ["usuario_laboratorio.usuario_id_usuario", "=", Auth::user()->id_usuario]
                        ]);
                    } else if ($area != "") { // Si solo el area esta definida
                        $obj_bd->where([
                            ["area.id_area", $area],
                            ["usuario_laboratorio.usuario_id_usuario", "=", Auth::user()->id_usuario]
                        ]);
                    } else {
                        $obj_bd->where([
                            ["usuario_laboratorio.usuario_id_usuario", "=", Auth::user()->id_usuario]
                        ]);
                    }
    
                return $obj_bd->get();
            }
        }
    }

    public static function listItem($id_proyecto_ep17)
    {
        $tableProyectoEP17 = new ProyectoEP17();
        return $tableProyectoEP17
            ->select(
                "laboratorio.*",
                "area.*",
                "analizador.*",
                "analito.*",
                "unidad.*",
                "proyecto_ep17.*",
                "proyecto_ep17.estado as estado_proyecto_ep17"
            )
            ->join("laboratorio", "laboratorio.id_laboratorio", "=", "proyecto_ep17.laboratorio_id_laboratorio")
            ->join("area", "area.id_area", "=", "proyecto_ep17.area_id_area")
            ->join("analizador", "analizador.id_analizador", "=", "proyecto_ep17.analizador_id_analizador")
            ->join("analito", "analito.id_analito", "=", "proyecto_ep17.analito_id_analito")
            ->join("unidad", "unidad.id_unidad", "=", "proyecto_ep17.unidad_id_unidad")
            ->where("id_proyecto_ep17", "=", $id_proyecto_ep17)
            ->first();
    }

    public function verUsuarios(Request $req){
        $proyectoEP17 = self::ListItem($req->id_reference);
        $users = UsuarioController::listUsersByLabForProject("proyecto_ep17","id_proyecto_ep17",$proyectoEP17->id_proyecto_ep17);
        return view("proyectoEP17.proyectoEP17Access")
            ->with("proyectoEP17", $proyectoEP17)
            ->with("users",$users);
    }

    public function edit(Request $req)
    {
        $proyectoEP17 = self::ListItem($req->id_reference);
        $laboratorios = LaboratorioController::listAll();
        $areas = AreaController::list();
        $analitos = AnalitoController::list();
        $unidades = UnidadController::list();
        $analizadores = AnalizadorController::list();

        return view("proyectoEP17.proyectoEP17Edit")
            ->with("laboratorios", $laboratorios)
            ->with("areas", $areas)
            ->with("analitos", $analitos)
            ->with("unidades", $unidades)
            ->with("analizadores", $analizadores)
            ->with("proyectoEP17", $proyectoEP17);
    }

    public function destroy(Request $req)
    {

        $this->historico = new ProyectoEP17Historico();
        $this->historico->store("destroy", $req);

        $this->tableProyectoEP17
            ->where("id_proyecto_ep17", $req->id)
            ->delete();
    }

    public function status(Request $req)
    {

        $this->historico = new ProyectoEP17Historico();
        $this->historico->store("status", $req);

        $statusNow = $this->tableProyectoEP17
            ->where("id_proyecto_ep17", $req->id)
            ->first()
            ->estado;

        $registroUpdate = $this->tableProyectoEP17
            ->where("id_proyecto_ep17", $req->id);

        if ($statusNow == 1) {
            $registroUpdate->update(["estado" => 0]);
        } else {
            $registroUpdate->update(["estado" => 1]);
        }
    }

    public function update(ProyectoEP17Request $req)
    {

        $this->historico = new ProyectoEP17Historico();
        $this->historico->store("update", $req);

        $proyectoEP17 = $this->tableProyectoEP17
            ->where("id_proyecto_ep17", $req->id)
            ->first();

        $proyectoEP17->update([
            "laboratorio_id_laboratorio" => $req->id_laboratorio,
            "area_id_area" => $req->id_area,
            "analito_id_analito" => $req->id_analito,
            "analizador_id_analizador" => $req->id_analizador,
            "unidad_id_unidad" => $req->id_unidad,
            "fecha" => $req->fecha,
            "n_lote_reactivo_1" => $req->n_lote_reactivo_1,
            "n_lote_reactivo_2" => $req->n_lote_reactivo_2,
            "decision_femenina" => $req->decision_femenina,
            "decision_masculina" => $req->decision_masculina,
            "pctb" => $req->pctb,
            "aps" => $req->aps
        ]);
    }
}
