<?php

namespace App\Http\Controllers;

// Controladores
use App\Http\Controllers\Controller;
use App\Http\Controllers\ProyectoEP17Controller;
use App\Http\Controllers\AnalitoEP17Controller;
use App\Http\Controllers\AnalitoController;
use App\Http\Controllers\NivelEP17Controller;

// Modelos
use App\ProyectoEP17;
use Illuminate\Support\Facades\DB;

// Requests
use Illuminate\Http\Request;
use Auth;

// Historicos
use App\Http\Historico\ProyectoEP17Historico;
use App\SuperUsuario;
use phpDocumentor\Reflection\Types\Integer;

//excel library
use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;


class ResultadoEP17Controller extends Controller
{

    protected $proyectoEP17;
    protected $historico;

    public function __construct()
    {
        $this->proyectoEP17 = new ProyectoEP17();
    }

    public function getDefaultValues(int $dias, int $replicas, int $muestras)
    {
        $resultados = array();
        for ($i = 0; $i < $dias; $i++) {
            $resultados[$i] = array();
            for ($j = 0; $j < $replicas; $j++) {
                $resultados[$i][$j] = array();
                for ($k = 0; $k < $muestras; $k++) $resultados[$i][$j][$k] = 0;
            }
        }
        return $resultados;
    }

    private function GetResultsProject($id)
    {
        $dMuestras = 5;
        $dReplicas = 4;
        $dDias = 3;
        $proyecto_EP17 = ProyectoEP17Controller::listItem($id);
        if ($proyecto_EP17->lote_blanco_1 == null){
            $proyecto_EP17->lote_blanco_1 = $this->getDefaultValues($dDias, $dReplicas, $dMuestras);
            $proyecto_EP17->lote_blanco_2 = $this->getDefaultValues($dDias, $dReplicas, $dMuestras);
            $proyecto_EP17->lote_deteccion_1 = $this->getDefaultValues($dDias, $dReplicas, $dMuestras);
            $proyecto_EP17->lote_deteccion_2 = $this->getDefaultValues($dDias, $dReplicas, $dMuestras);
            $proyecto_EP17->lote_cuantificacion_1 = $this->getDefaultValues($dDias, $dReplicas, $dMuestras);
            $proyecto_EP17->lote_cuantificacion_2 = $this->getDefaultValues($dDias, $dReplicas, $dMuestras);
            $proyecto_EP17->valores_referencia = array_fill(0, $dMuestras, 0);
        }
        else{
            $proyecto_EP17->lote_blanco_1 = json_decode($proyecto_EP17->lote_blanco_1);
            $proyecto_EP17->lote_blanco_2 = json_decode($proyecto_EP17->lote_blanco_2);
            $proyecto_EP17->lote_deteccion_1 = json_decode($proyecto_EP17->lote_deteccion_1);
            $proyecto_EP17->lote_deteccion_2 = json_decode($proyecto_EP17->lote_deteccion_2);
            $proyecto_EP17->lote_cuantificacion_1 = json_decode($proyecto_EP17->lote_cuantificacion_1);
            $proyecto_EP17->lote_cuantificacion_2 = json_decode($proyecto_EP17->lote_cuantificacion_2);
            $proyecto_EP17->valores_referencia = json_decode($proyecto_EP17->valores_referencia);
        }
        $proyecto_EP17->nDias = count($proyecto_EP17->lote_blanco_1);
        $proyecto_EP17->nReplicas = count($proyecto_EP17->lote_blanco_1[0]);
        $proyecto_EP17->nMuestras = count($proyecto_EP17->lote_blanco_1[0][0]);
        return $proyecto_EP17;
    }

    public function edit(Request $req)
    {
        $proyecto_EP17 = $this->GetResultsProject($req->id_reference);
        return view("resultadoEP17.resultadoEP17Edit")
            ->with("proyecto_EP17", $proyecto_EP17);
    }

    public function update(Request $req)
    {
        $this->historico = new ProyectoEP17Historico();
        $this->historico->store("updateResults", $req);

        $proyectoEP17 = $this->proyectoEP17
            ->where("id_proyecto_ep17", $req->id)
            ->first();
        $proyectoEP17->update([
            "lote_blanco_1" => json_decode($req->lote_blanco_1),
            "lote_blanco_2" => json_decode($req->lote_blanco_2),
            "lote_deteccion_1" => json_decode($req->lote_deteccion_1),
            "lote_deteccion_2" => json_decode($req->lote_deteccion_2),
            "lote_cuantificacion_1" => json_decode($req->lote_cuantificacion_1),
            "lote_cuantificacion_2" => json_decode($req->lote_cuantificacion_2),
            "valores_referencia" => json_decode($req->valores_referencia)
        ]);
    }

    private function stackAndOrder($array)
    {
        $stack = [];
        foreach ($array as $item) {
            foreach ($item as $item2) {
                foreach ($item2 as $item3) {
                    $stack[] = $item3;
                }
            }
        }
        sort($stack);
        return $stack;
    }

    private function getLobLote($orderedItems, $indexNum1, $indexNum2){
        $lob_lote_1 = $orderedItems[$indexNum1 - 1];
        $lob_lote_2 = $orderedItems[$indexNum2 - 1];
        $averageLob = ($lob_lote_1 + $lob_lote_2) / 2;
        return [
            "valPosition1" => $lob_lote_1,
            "valPosition2" => $lob_lote_2,
            "averageLob" => $averageLob
        ];
    }
    

    private function getResultsBlankProjectAndCalc($results)
    {
        $totalItems = $results->nDias * $results->nReplicas * $results->nMuestras;
        $rankPosition = .5 + ($totalItems * $results->pctb);
        $indexNum1 = (int) $rankPosition;
        $indexNum2 = $indexNum1 != $rankPosition ? $indexNum1 + 1 : $indexNum1;
        $orderedItems1 = $this->stackAndOrder($results->lote_blanco_1);
        $orderedItems2 = $this->stackAndOrder($results->lote_blanco_2);
        $lobLote1 = $this->getLobLote($orderedItems1, $indexNum1, $indexNum2);
        $lobLote2 = $this->getLobLote($orderedItems2, $indexNum1, $indexNum2);
        return [
            "totalItems" => $totalItems,
            "rankPosition" => $rankPosition,
            "indexNum1" => $indexNum1,
            "indexNum2" => $indexNum2,
            "orderedItems1" => $orderedItems1,
            "orderedItems2" => $orderedItems2,
            "lobLote1" => $lobLote1,
            "lobLote2" => $lobLote2,
            "averageLob" => ($lobLote1["averageLob"] + $lobLote2["averageLob"]) / 2,
        ];
    }

    private function calcAverageAndSD($array){
        $average = array_sum($array) / count($array);
        $sumOfSquares = array_reduce($array, function($carry, $item) use ($average) {
            return $carry + pow($item - $average, 2);
        }, 0);
        $sd = round(sqrt($sumOfSquares / (count($array) - 1)), 6);
        return [
            "average" => round($average, 6),
            "sd" => $sd
        ];
    }

    private function calcSampleData($array, $lodN) {
        $averageAndSD = $this->calcAverageAndSD($array);
        $sd2 = round(pow($averageAndSD["sd"], 2), 6);
        $sd2N = $sd2 * ($lodN - 1);
        return [
            "average" => $averageAndSD["average"],
            "sd" => $averageAndSD["sd"],
            "sd2" => $sd2,
            "sd2N" => $sd2N
        ];
    }

    private function getDataSamples($resultsLote, $nSamples){
        $dataSamples = [];
        for ($i = 0; $i < $nSamples; $i++){
            $dataSamples[$i] = [];
            foreach ($resultsLote as $item){
                foreach ($item as $item2){
                    $dataSamples[$i][] = $item2[$i];
                }
            }
        }
        return $dataSamples;
    }

    private function getResultsDetectionProjectAndCalc($results, $lobLote1, $lobLote2){
        $lodN = $results->nDias * $results->nReplicas;
        $lodNT = ($lodN - 1) * $results->nMuestras;
        $dataSamples1 = $this->getDataSamples($results->lote_deteccion_1, $results->nMuestras);
        $dataSamples2 = $this->getDataSamples($results->lote_deteccion_2, $results->nMuestras);
        $averageAndSD1 = [];
        $averageAndSD2 = [];
        for ($i = 0; $i < $results->nMuestras; $i++){
            $averageAndSD1[$i] = $this->calcSampleData($dataSamples1[$i], $lodN);
            $averageAndSD2[$i] = $this->calcSampleData($dataSamples2[$i], $lodN);
        }
        $totalSd2N1 = 0;
        $totalSd2N2 = 0;
        foreach ($averageAndSD1 as $item) $totalSd2N1 += $item["sd2N"];
        foreach ($averageAndSD2 as $item) $totalSd2N2 += $item["sd2N"];
        $sdLo1 = round(sqrt($totalSd2N1 / $lodNT), 6);
        $sdLo2 = round(sqrt($totalSd2N2 / $lodNT), 6);
        $cpVal =  round(1.645/(1-(1/(4*$lodNT))), 6);
        $lodLote1 = round($lobLote1["averageLob"] + $cpVal * $sdLo1, 6);
        $lodLote2 = round($lobLote2["averageLob"] + $cpVal * $sdLo2, 6);
        $lodAvg = round(($lodLote1 + $lodLote2) / 2, 6);
        return [
            "lodN" => $lodN,
            "lodNT" => $lodNT,
            "averageAndSD1" => $averageAndSD1,
            "averageAndSD2" => $averageAndSD2,
            "totalSd2N1" => $totalSd2N1,
            "totalSd2N2" => $totalSd2N2,
            "sdLo1" => $sdLo1,
            "sdLo2" => $sdLo2,
            "cpVal" => $cpVal,
            "lodLote1" => $lodLote1,
            "lodLote2" => $lodLote2,
            "lodAvg" => $lodAvg
        ];
    }

    private function getResultsQuantificationProjectAndCalc($results){
        $dataSamples1 = $this->getDataSamples($results->lote_cuantificacion_1, $results->nMuestras);
        $dataSamples2 = $this->getDataSamples($results->lote_cuantificacion_2, $results->nMuestras);
        $averageAndSD1 = [];
        $averageAndSD2 = [];
        $bias1 = [];
        $bias2 = [];
        $te1 = [];
        $te2 = [];
        $averageTe = [];
        for ($i = 0; $i < $results->nMuestras; $i++) {
            $averageAndSD1[$i] = $this->calcAverageAndSD($dataSamples1[$i]);
            $averageAndSD2[$i] = $this->calcAverageAndSD($dataSamples2[$i]);
            $bias1[$i] = round($averageAndSD1[$i]["average"] - $results->valores_referencia[$i], 6);
            $bias2[$i] = round($averageAndSD2[$i]["average"] - $results->valores_referencia[$i], 6);
            
            $valRef1 = $results->valores_referencia[$i];
            $avg1 = $averageAndSD1[$i]["average"];
            $sd1 = $averageAndSD1[$i]["sd"];
            $valRef2 = $results->valores_referencia[$i];
            $avg2 = $averageAndSD2[$i]["average"];
            $sd2 = $averageAndSD2[$i]["sd"];
            
            $te1[$i] = round(
                ($valRef1 != 0 ? abs($bias1[$i] / $valRef1 * 100) : 0) +
                ($avg1 != 0 ? abs($sd1 / $avg1 * 100) : 0),
                6
            );
            $te2[$i] = round(
                ($valRef2 != 0 ? abs($bias2[$i] / $valRef2 * 100) : 0) +
                ($avg2 != 0 ? abs($sd2 / $avg2 * 100) : 0),
                6
            );
            
            $averageTe[$i] = round(($te1[$i] + $te2[$i]) / 2, 6);
        }
        $loq1 = min(array_column($averageAndSD1, "average"));
        $loq2 = min(array_column($averageAndSD2, "average"));
        return [
            "averageAndSD1" => $averageAndSD1,
            "averageAndSD2" => $averageAndSD2,
            "loq1" => $loq1,
            "loq2" => $loq2,
            "bias1" => $bias1,
            "bias2" => $bias2,
            "te1" => $te1,
            "te2" => $te2,
            "averageTe" => $averageTe
        ];
    }

    public function informe(Request $req)
    {
        $proyectoEP17 = $this->GetResultsProject($req->id_reference);
        $resultsB = $this->getResultsBlankProjectAndCalc($proyectoEP17);
        $resultsD = $this->getResultsDetectionProjectAndCalc($proyectoEP17, $resultsB['lobLote1'], $resultsB['lobLote2']);
        $resultsQ = $this->getResultsQuantificationProjectAndCalc($proyectoEP17);
        $cliente = SuperUsuario::query()->where('id', Auth::user()->super_admin_id)->first();
        return view("resultadoEP17.resultadoEP17Informe")
            ->with("cliente", $cliente)
            ->with("proyectoEP17", $proyectoEP17)
            ->with("resultsB", $resultsB)
            ->with("resultsD", $resultsD)
            ->with("resultsQ", $resultsQ);
    }

    public function informePdf(Request $req)
    {
        $proyectoEP17 = $this->GetResultsProject($req->id_reference);
        $resultsB = $this->getResultsBlankProjectAndCalc($proyectoEP17);
        $resultsD = $this->getResultsDetectionProjectAndCalc($proyectoEP17, $resultsB['lobLote1'], $resultsB['lobLote2']);
        $resultsQ = $this->getResultsQuantificationProjectAndCalc($proyectoEP17);
        $cliente = SuperUsuario::query()->where('id', Auth::user()->super_admin_id)->first();
        return view("resultadoEP17.resultadoEP17InformePdf")
            ->with("cliente", $cliente)
            ->with("proyectoEP17", $proyectoEP17)
            ->with("resultsB", $resultsB)
            ->with("resultsD", $resultsD)
            ->with("resultsQ", $resultsQ);
    }
}
